@@ -62,6 +62,7 @@ class PuppetLint
       :MATCH   => true,
       :NOMATCH => true,
       :COMMA   => true,
+      :LBRACK  => true,
     }
 
     # Internal: An Array of Arrays containing tokens that can be described by
@@ -69,6 +70,7 @@ class PuppetLint
     # name of the token as a Symbol and a regular expression describing the
     # value of the token.
     KNOWN_TOKENS = [
+      [:TYPE, /\A(Integer|Float|Boolean|Regexp|String|Array|Hash|Resource|Class|Collection|Scalar|Numeric|CatalogEntry|Data|Tuple|Struct|Optional|NotUndef|Variant|Enum|Pattern|Any|Callable|Type|Runtime|Undef|Default)/],
       [:CLASSREF, /\A(((::){0,1}[A-Z][-\w]*)+)/],
       [:NUMBER, /\A\b((?:0[xX][0-9A-Fa-f]+|0?\d+(?:\.\d+)?(?:[eE]-?\d+)?))\b/],
       [:NAME, /\A(((::)?[a-z0-9][-\w]*)(::[a-z0-9][-\w]*)*)/],
@@ -195,11 +197,12 @@ class PuppetLint
 
           elsif mlcomment = chunk[/\A(\/\*.*?\*\/)/m, 1]
             length = mlcomment.size
+            mlcomment_raw = mlcomment.dup
             mlcomment.sub!(/\A\/\* ?/, '')
             mlcomment.sub!(/ ?\*\/\Z/, '')
-            mlcomment.gsub!(/ *\* ?/, '')
-            mlcomment.strip!
+            mlcomment.gsub!(/^ *\*/, '')
             tokens << new_token(:MLCOMMENT, mlcomment, length)
+            tokens.last.raw = mlcomment_raw
 
           elsif chunk.match(/\A\/.*?\//) && possible_regex?
             str_content = StringScanner.new(code[i+1..-1]).scan_until(/(\A|[^\\])(\\\\)*\//m)
